pub fn to_bytes_custom<T, F: AsRef<str>>(
value: T,
fmt: &FortFormat,
fields: Option<&[F]>,
settings: &SerSettings,
) -> SResult<Vec<u8>>where
T: Serialize,Expand description
Serialize a value into a sequence of bytes with full control over how the serialization is done.
Use this method if you need to pass custom settings. See SerSettings for available
options. Pass None for fields if there are no field names to match up. Note that
calling without fields will require annotating the type F for the fields, so you would
call this as to_string_custom::<_, &str>(...) in that case.